actions
open | /demo/actions.html |
assertAttribute | toggleclass-button@class | button click cursorPointer
click | toggleclass-button |
assertAttribute | toggleclass-button@class | button click cursorPointer selected
click | toggleclass-button |
assertAttribute | toggleclass-button@class | button click cursorPointer
assertAttribute | server-toggleclass-button@class | button click cursorPointer
click | server-toggleclass-button |
waitForAttribute | server-toggleclass-button@class | button click cursorPointer selected
assertAttribute | server-toggleclass-button@class | button click cursorPointer selected
click | server-toggleclass-button |
waitForAttribute | server-toggleclass-button@class | button click cursorPointer
assertAttribute | server-toggleclass-button@class | button click cursorPointer
assertAttribute | addclass-button@class | button click cursorPointer
click | addclass-button |
waitForAttribute | addclass-button@class | button click cursorPointer selected
assertAttribute | addclass-button@class | button click cursorPointer selected
assertAttribute | server-addclass-button@class | button click cursorPointer
click | server-addclass-button |
waitForAttribute | server-addclass-button@class | button click cursorPointer selected
assertAttribute | server-addclass-button@class | button click cursorPointer selected
assertAttribute | removeclass-button@class | button click cursorPointer selected
click | removeclass-button |
waitForAttribute | removeclass-button@class | button click cursorPointer
assertAttribute | removeclass-button@class | button click cursorPointer
assertAttribute | server-removeclass-button@class | button click cursorPointer selected
click | server-removeclass-button |
waitForAttribute | server-removeclass-button@class | button click cursorPointer
assertAttribute | server-removeclass-button@class | button click cursorPointer